@@ -16,7 +16,7 @@ class Analysis:
     _mutable_fields_ = ['dataset_id', 'description', 'name',  'predictions',
                         'model', 'predictors', 'private', 'runs']
 
-    _aliased_methods_ = ['delete', 'bundle', 'compile', 'generate_report',
+    _aliased_methods_ = ['delete', 'get_bundle', 'compile', 'generate_report',
                          'get_report', 'upload_neurovault', 'get_uploads',
                          'plot_report', 'get_design_matrix']
 
@@ -92,15 +92,15 @@ class Analysis:
 
     def get_status(self):
         """ Get compilation status """
-        return self._getter_wrapper('status')
+        return self._getter_wrapper('get_status')
 
     def get_resources(self):
         """ Get analysis resources """
-        return self._getter_wrapper('resources')
+        return self._getter_wrapper('get_resources')
 
     def get_full(self):
         """ Get full analysis representation """
-        return self._getter_wrapper('full')
+        return self._getter_wrapper('get_full')
 
     def clone(self, dataset_id=None):
         """ Clone current analysis, and return a new Analysis object
@@ -137,7 +137,7 @@ class Analyses(Base):
         """
         return self._client._delete(self._base_path_, id=id)
 
-    def bundle(self, id, filename=None):
+    def get_bundle(self, id, filename=None):
         """ Get analysis bundle
         :param str id: Analysis hash_id.
         :param str, object filename: Optional filename to save bundle to
@@ -215,8 +215,10 @@ class Analyses(Base):
             set([p['name'] for p in public_preds])
         if private_preds:
             # Get Predictor IDs
-            predictors += [p['id'] for p in self._client.user.get_predictors(
-                run_id=run_id, name=private_preds)]
+            for pred in private_preds:
+                predictors += [p['id']
+                               for p in self._client.user.get_predictors(
+                                   run_id=run_id, name=pred)]
 
         if len(predictors) != len(predictor_names):
             raise ValueError(
@@ -248,17 +250,18 @@ class Analyses(Base):
         """
         return Analysis(analyses=self, **self.get(id=id))
 
-    def compile(self, id):
+    def compile(self, id,  build=True):
         """ Submit analysis for complilation
         :param str id: Analysis hash_id.
+        :param bool build: Build pybids object and verify compilation
         :return: client response object
         """
-        return self.post(id=id, sub_route='compile')
+        return self.post(id=id, sub_route='compile', params=dict(build=build))
 
     def generate_report(self, id, run_id=None):
         """ Submit analysis for report generation
         :param str id: Analysis hash_id.
-        :param bool run_id: Optional run_id to constrain report.
+        :param int run_id: Optional run_id to constrain report.
         :return: client response object
         """
         return self.post(id=id, sub_route='report', params=dict(run_id=run_id))
@@ -273,7 +276,7 @@ class Analyses(Base):
         if loop_wait:
             while report['status'] == 'PENDING':
                 time.sleep(2)
-                report = self.get_report(id=id, run_id=run_id)
+                report = self.get(id=id, sub_route='report', run_id=run_id)
 
         return report
 
@@ -289,7 +292,7 @@ class Analyses(Base):
         if report['status'] == 'OK':
             return report['result']['design_matrix']
         else:
-            return report['status']
+            return None
 
     def plot_report(self, id, run_id=None, plot_type='design_matrix_plot',
                     loop_wait=True):
@@ -308,10 +311,11 @@ class Analyses(Base):
             for p in report['result'][plot_type]:
                 altair.display.vegalite(p)
 
-        return report['status']
+        return None
 
     def upload_neurovault(self, id, validation_hash, subject_paths=None,
                           group_paths=None, collection_id=None, force=False,
+                          cli_version=None, fmriprep_version=None,
                           n_subjects=None):
         """ Submit analysis for report generation
         :param str id: Analysis hash_id.
@@ -319,6 +323,8 @@ class Analyses(Base):
         :param list(str) subject_paths: List of image paths.
         :param list(str) group_paths: List of image paths.
         :param bool force: Force upload with unique timestamped name.
+        :param str: neuroscout-cli version at runtime
+        :param str: fmriprep version at runtime
         :param int n_subjects: Number of subjects in analysis.
         :return: client response object
         """
@@ -330,6 +336,7 @@ class Analyses(Base):
 
             return tmaps + group_paths
 
+        req = None
         # Do group, then subject level
         if group_paths is not None:
             print("Uploading group images")
@@ -338,6 +345,7 @@ class Analyses(Base):
                 req = self.post(
                     id=id, sub_route='upload', files=files, level='GROUP',
                     validation_hash=validation_hash, force=force,
+                    fmriprep_version=fmriprep_version, cli_version=cli_version,
                     n_subjects=n_subjects, collection_id=collection_id)
                 if collection_id is None:
                     collection_id = req['collection_id']
@@ -349,10 +357,14 @@ class Analyses(Base):
                 req = self.post(
                     id=id, sub_route='upload', files=files, level='SUBJECT',
                     validation_hash=validation_hash, force=force,
+                    fmriprep_version=fmriprep_version, cli_version=cli_version,
                     collection_id=collection_id)
                 if collection_id is None:
                     collection_id = req['collection_id']
 
+        if req is None:
+            print("No images found")
+
         return req
 
     def get_uploads(self, id):
@@ -362,7 +374,7 @@ class Analyses(Base):
         """
         return self.get(id=id, sub_route='upload')
 
-    def full(self, id):
+    def get_full(self, id):
         """ Get full analysis object (including runs and predictors)
         :param str id: Analysis hash_id.
         :return: client response object
@@ -379,14 +391,14 @@ class Analyses(Base):
         return self.post(id=id, sub_route='fill',
                          params=dict(partial=partial, dryrun=dryrun))
 
-    def resources(self, id):
+    def get_resources(self, id):
         """ Get analysis resources
         :param str id: Analysis hash_id.
         :return: client response object
         """
         return self.get(id=id, sub_route='resources')
 
-    def status(self, id):
+    def get_status(self, id):
         """ Get analysis status
         :param str id: Analysis hash_id.
         :return: client response object
